@@ -28,8 +28,8 @@ perl -MDevel::Cover t/00_CappedCollection/10_quit.t
 perl -MDevel::Cover t/00_CappedCollection/11_max_datasize.t
 perl -MDevel::Cover t/00_CappedCollection/12_last_errorcode.t
 perl -MDevel::Cover t/00_CappedCollection/13_name.t
-perl -MDevel::Cover t/00_CappedCollection/15_min_cleanup_bytes.t
-perl -MDevel::Cover t/00_CappedCollection/17_min_cleanup_items.t
+perl -MDevel::Cover t/00_CappedCollection/15_cleanup_bytes.t
+perl -MDevel::Cover t/00_CappedCollection/17_cleanup_items.t
 perl -MDevel::Cover t/00_CappedCollection/18_info.t
 perl -MDevel::Cover t/00_CappedCollection/19_drop.t
 perl -MDevel::Cover t/00_CappedCollection/20_cleaning.t
@@ -43,5 +43,3 @@ perl -MDevel::Cover xt/release/00_CappedCollection/98_pod.t
 perl -MDevel::Cover xt/release/00_CappedCollection/99_pod_coverage.t
 
 cover
-
-
